# vim: set sw=4 ts=4 et:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:           gnunet
Version:        0.9.5a
Release:        1.2
License:        GPL-3.0
Summary:        Security focused Peer-to-Peer Framework
Url:            http://gnunet.org
Group:          Productivity/Networking/Other
Source:         ftp://ftp.gnu.org/gnu/gnunet/gnunet-%{version}.tar.gz
Source1:        gnunet.init
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch1:         gnunet-fix_postgresql_include.patch
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch2:         gnunet-etc_for_config.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  glpk-devel
BuildRequires:  gmp-devel
BuildRequires:  guile-devel
BuildRequires:  libadns-devel
BuildRequires:  libcares-devel
BuildRequires:  libcurl-devel
BuildRequires:  libesmtp-devel
BuildRequires:  libextractor-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libidn-devel
BuildRequires:  libmicrohttpd-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libqt4-devel
BuildRequires:  libqt4-devel
BuildRequires:  libtool
BuildRequires:  libunistring-devel
BuildRequires:  make
BuildRequires:  postgresql-devel
BuildRequires:  sqlite3-devel
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Provides:       gnunetd = %{version}
Provides:       GNUnet = %{version}
Provides:       GNUnetd = %{version}

%description
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

GNUnet is a part of the GNU project (http://www.gnu.org/).

%package devel
Summary:        Security focused Peer-to-Peer Framework
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

%package mysql
Summary:        MySQL Storage Backend for %{name}
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}

%description mysql
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

%package postgresql
Summary:        PostgreSQL Storage Backend for %{name}
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}

%description postgresql
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

%package sqlite
Summary:        SQLite Storage Backend for %{name}
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}

%description sqlite
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

%prep
%setup -q
%patch1
%patch2

%build
autoreconf -fiv

%configure \
    --with-daemon-home-dir="%{_localstatedir}/lib/gnunet" \
    --with-daemon-config-dir="%{_sysconfdir}"

make %{?_smp_mflags} V=1 \
    pkgcfgdir="%{_sysconfdir}/gnunet"

%install
%makeinstall \
    pkgcfgdir="%{_sysconfdir}/gnunet"

# get rid of static libraries
find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;

rm -rf %{buildroot}%{_datadir}/doc/%{name}

# install init script
install -D -m0755 "%{SOURCE1}" "%{buildroot}%{_initddir}/%{name}"
install -d "%{buildroot}%{_sbindir}"
ln -s "../../etc/init.d/%{name}" "%{buildroot}%{_sbindir}/rc%{name}"

install -d "%{buildroot}%{_localstatedir}/lib/gnunet"

cat<<EOF > "%{buildroot}%{_sysconfdir}/gnunet.conf"
[PATHS]
SERVICEHOME = %{_localstatedir}/lib/gnunet
DEFAULTCONFIG = %{_sysconfdir}/gnunet.conf
EOF

%find_lang gnunet

%pre
/usr/sbin/groupadd -r gnunet || :
/usr/sbin/useradd -r -g gnunet -c "GNUnet daemon" -d /var/lib/gnunet gnunet || :

%post -p /sbin/ldconfig

%preun
%stop_on_removal %{name}

%postun
/sbin/ldconfig
%restart_on_update %{name}
%insserv_cleanup


%files -f gnunet.lang
%defattr(-,root,root)
%{_bindir}/*
%doc %{_mandir}/man1/gnunet*
%doc %{_mandir}/man5/gnunet*
%doc COPYING README
%{_datadir}/gnunet
%{_libdir}/libgnunet*.so.*
%{_libdir}/gnunet
# plugin dir
%exclude %{_libdir}/gnunet/libgnunet_plugin_datastore_mysql.so
%exclude %{_libdir}/gnunet/libgnunet_plugin_datacache_postgres.so
%exclude %{_libdir}/gnunet/libgnunet_plugin_datastore_postgres.so
%exclude %{_libdir}/gnunet/libgnunet_plugin_namestore_postgres.so
%exclude %{_libdir}/gnunet/libgnunet_plugin_datacache_sqlite.so
%exclude %{_libdir}/gnunet/libgnunet_plugin_datastore_sqlite.so
%exclude %{_libdir}/gnunet/libgnunet_plugin_namestore_sqlite.so

%config(noreplace) %{_sysconfdir}/gnunet.conf
%dir %{_sysconfdir}/gnunet
%config %{_sysconfdir}/gnunet/*.conf
%{_sysconfdir}/init.d/gnunet
%{_sbindir}/rcgnunet
%{_localstatedir}/lib/gnunet

%files mysql
%defattr(-,root,root)
%{_libdir}/gnunet/libgnunet_plugin_datastore_mysql.so

%files postgresql
%defattr(-,root,root)
%{_libdir}/gnunet/libgnunet_plugin_datacache_postgres.so
%{_libdir}/gnunet/libgnunet_plugin_datastore_postgres.so
%{_libdir}/gnunet/libgnunet_plugin_namestore_postgres.so

%files sqlite
%defattr(-,root,root)
%{_libdir}/gnunet/libgnunet_plugin_datacache_sqlite.so
%{_libdir}/gnunet/libgnunet_plugin_datastore_sqlite.so
%{_libdir}/gnunet/libgnunet_plugin_namestore_sqlite.so

%files devel
%defattr(-,root,root)
%{_includedir}/gnunet
%{_libdir}/pkgconfig/*
%{_libdir}/libgnunet*.so

%changelog
* Thu Dec 19 2013 sleep_walker@suse.cz
- bump to 0.9.5a
- patches refreshed
- simplify the spec
* Thu Mar  1 2012 pascal.bleser@opensuse.org
- update to 0.9.2: too many changes to list, details are in ChangeLog
* Thu Dec  1 2011 pascal.bleser@opensuse.org
- update to 0.9.0:
  * major change of the architecture and a rewrite of most of the system
  * improvements:
  - a new multi-process architecture
  - a new VPN subsystem, a new setup tool (including automated correctness tests for the configuration), support for non-anonymous mesh routing, data transport over HTTPS and WLAN, peer discovery in the LAN via broadcast (IPv4) and multicast (IPv6), improved connectivity via NAT traversal, an event-driven execution model providing significant performance improvements, and power publishing for file sharing to improve content replication.
* Tue Mar  1 2011 pascal.bleser@opensuse.org
- 0.8.1b, moved to new packman infrastructure
